'use server';

import 'server-only';
import { createServerClient, type Profile } from '@/utils/supabase';
import { getUser } from '@/lib/actions';
import type { Result } from './index';

export const getProfile = async (): Promise<Result<Profile>> => {
  try {
    const user = await getUser();
    if (!user) throw new Error('User not found');
    const supabase = await createServerClient();
    const { data, error } = await supabase
      .from('profiles')
      .select('*')
      .eq('id', user.id)
      .single();
    if (error) throw error;
    return { success: true, data: data as Profile };
  } catch (error) {
    console.error('Could not get profile!', error);
    return {
      success: false,
      error:
        error instanceof Error
          ? error.message
          : 'Unknown error getting profile',
    };
  }
};
